@@ -1,7 +1,7 @@
 # ABSTRACT: turns baubles into trinkets
 package Text::vCard::Precisely::V4;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -222,7 +222,7 @@ coerce 'v4Address'
     => via { [ map { Text::vCard::Precisely::V4::Node::Address->new($_) } @$_ ] };
 has adr => ( is => 'rw', isa => 'v4Address', coerce => 1 );
 
-=head2 email()
+=head3 email()
 
 The format is SAME as 3.0
 
@@ -326,9 +326,10 @@ coerce 'v4Node'
     => via {
         my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
         return [ Text::vCard::Precisely::V4::Node->new({
-                name => $_->{'name'} || $name,
-                types => $_->{'types'} || [],
-                content => $_->{'content'} || croak "No value in HashRef!",
+            name => $_->{'name'} || $name,
+            types => $_->{'types'} || [],
+            sort_as => $_->{'sort_as'},
+            content => $_->{'content'} || croak "No value in HashRef!",
         }) ]
  };
 coerce 'v4Node'
@@ -336,9 +337,10 @@ coerce 'v4Node'
     => via {
      my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
          return [ map { Text::vCard::Precisely::V4::Node->new({
-         name => $_->{'name'} || $name,
-         types => $_->{'types'} || [],
-         content => $_->{'content'} || croak "No value in HashRef!",
+             name => $_->{'name'} || $name,
+             types => $_->{'types'} || [],
+             sort_as => $_->{'sort_as'},
+             content => $_->{'content'} || croak "No value in HashRef!",
      }) } @$_ ]
 };
 has [qw|note org title role categories fn nickname lang impp xml geo key|]
@@ -532,16 +534,6 @@ sub agent {
 
 1;
 
-=head2 TODO
- 
-=over
-
-=item 
-
-SORT-AS param in N,FN,ORG is NOT available
-
-=back
-
 =head2 aroud UTF-8
 
 If you want to send precisely the vCard with UTF-8 characters to the B<ALMOST> of smartphones, Use 3.0
